==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserFactorPushTransactionTimeoutAllOfLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksVerifyVerify;
import com.okta.sdk.resource.model.UserFactor;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorPushTransactionTimeoutAllOfLinks
 */
@JsonPropertyOrder({ UserFactorPushTransactionTimeoutAllOfLinks.JSON_PROPERTY_VERIFY,
        UserFactorPushTransactionTimeoutAllOfLinks.JSON_PROPERTY_FACTOR })
@JsonTypeName("UserFactorPushTransactionTimeout_allOf__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserFactorPushTransactionTimeoutAllOfLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_VERIFY = "verify";
    private LinksVerifyVerify verify;

    public static final String JSON_PROPERTY_FACTOR = "factor";
    private UserFactor factor;

    public UserFactorPushTransactionTimeoutAllOfLinks() {
    }

    public UserFactorPushTransactionTimeoutAllOfLinks verify(LinksVerifyVerify verify) {

        this.verify = verify;
        return this;
    }

    /**
     * Get verify
     *
     * @return verify
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksVerifyVerify getVerify() {
        return verify;
    }

    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVerify(LinksVerifyVerify verify) {
        this.verify = verify;
    }

    public UserFactorPushTransactionTimeoutAllOfLinks factor(UserFactor factor) {

        this.factor = factor;
        return this;
    }

    /**
     * Get factor
     *
     * @return factor
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_FACTOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserFactor getFactor() {
        return factor;
    }

    @JsonProperty(JSON_PROPERTY_FACTOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setFactor(UserFactor factor) {
        this.factor = factor;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorPushTransactionTimeoutAllOfLinks userFactorPushTransactionTimeoutAllOfLinks = (UserFactorPushTransactionTimeoutAllOfLinks) o;
        return Objects.equals(this.verify, userFactorPushTransactionTimeoutAllOfLinks.verify)
                && Objects.equals(this.factor, userFactorPushTransactionTimeoutAllOfLinks.factor);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(verify, factor);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorPushTransactionTimeoutAllOfLinks {\n");
        sb.append("    verify: ").append(toIndentedString(verify)).append("\n");
        sb.append("    factor: ").append(toIndentedString(factor)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/UserFactorPushTransactionTimeoutAllOfLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksVerifyVerify;
import com.okta.sdk.resource.model.UserFactor;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorPushTransactionTimeoutAllOfLinks
 */
@JsonPropertyOrder({ UserFactorPushTransactionTimeoutAllOfLinks.JSON_PROPERTY_VERIFY,
        UserFactorPushTransactionTimeoutAllOfLinks.JSON_PROPERTY_FACTOR })
@JsonTypeName("UserFactorPushTransactionTimeout_allOf__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class UserFactorPushTransactionTimeoutAllOfLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_VERIFY = "verify";
    private LinksVerifyVerify verify;

    public static final String JSON_PROPERTY_FACTOR = "factor";
    private UserFactor factor;

    public UserFactorPushTransactionTimeoutAllOfLinks() {
    }

    public UserFactorPushTransactionTimeoutAllOfLinks verify(LinksVerifyVerify verify) {

        this.verify = verify;
        return this;
    }

    /**
     * Get verify
     *
     * @return verify
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksVerifyVerify getVerify() {
        return verify;
    }

    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVerify(LinksVerifyVerify verify) {
        this.verify = verify;
    }

    public UserFactorPushTransactionTimeoutAllOfLinks factor(UserFactor factor) {

        this.factor = factor;
        return this;
    }

    /**
     * Get factor
     *
     * @return factor
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_FACTOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserFactor getFactor() {
        return factor;
    }

    @JsonProperty(JSON_PROPERTY_FACTOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setFactor(UserFactor factor) {
        this.factor = factor;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorPushTransactionTimeoutAllOfLinks userFactorPushTransactionTimeoutAllOfLinks = (UserFactorPushTransactionTimeoutAllOfLinks) o;
        return Objects.equals(this.verify, userFactorPushTransactionTimeoutAllOfLinks.verify)
                && Objects.equals(this.factor, userFactorPushTransactionTimeoutAllOfLinks.factor);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(verify, factor);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorPushTransactionTimeoutAllOfLinks {\n");
        sb.append("    verify: ").append(toIndentedString(verify)).append("\n");
        sb.append("    factor: ").append(toIndentedString(factor)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
